==> mit-scheme-c-9.1.1.tar.gz: mit-scheme-c-9.1.1/src/compiler/base/switch.c <==
/* Emacs: this is -*- C -*- code, */
/* generated 2011-11-08T22:51:34-08 by Liar version 4.118. */

#include "liarc.h"

#define LABEL_5 3
#define LABEL_6 5
#define ENVIRONMENT_LABEL_3 12
#define DEBUGGING_LABEL_2 11
#define OBJECT_1 10
#define OBJECT_0 9
#define GLOBAL_EXECUTE_CACHE_4 7
#define FREE_REFERENCES_LABEL_0 6
#define NUMBER_OF_LINKER_SECTIONS_1 1

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
switch_so_055d1f72062c8b11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5);
      goto label_3;

    case 1:
      current_block = (Rpc - LABEL_6);
      goto expression_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_1)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_5])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_3)
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd6.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_1]);
  (Rsp [2]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_4]));

INVOKE_INTERFACE_TARGET_4
}

int
decl_switch_so_055d1f72062c8b11 (void)
{
  return (0);
}

DECLARE_COMPILED_CODE ("switch.so", 2, decl_switch_so_055d1f72062c8b11, switch_so_055d1f72062c8b11)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_switch_so_data_055d1f72062c8b11 [1141] =
  "\x23\x01\x51\x1d\x0c\x06\x0d\x0d\x08\x89\x08\x88\x0d\x07\x07\x06"
  "\x06\x06\x06\x06\x07\x07\x07\x07\x06\x06\x07\x07\x07\x07\x07\x07"
  "\x07\x06\x06\x06\x06\x06\x07\x07\x07\x17\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x17\x28\x0d\x26\x22\x29\x22"
  "\x29\x21\x17\x02\x59\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f"
  "\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f"
  "\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69"
  "\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31"
  "\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x62\x61"
  "\x73\x65\x2f\x73\x77\x69\x74\x63\x68\x2e\x69\x6e\x66\x09\x75\x75"
  "\x6f\x2d\x6c\x69\x6e\x6b\x04\x61\x6c\x6c\x07\x68\x79\x62\x72\x69"
  "\x64\x20\x17\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x70\x68\x61\x73"
  "\x65\x2d\x77\x72\x61\x70\x70\x65\x72\x28\x63\x6f\x6d\x70\x69\x6c"
  "\x65\x72\x3a\x64\x65\x66\x61\x75\x6c\x74\x2d\x74\x6f\x70\x2d\x6c"
  "\x65\x76\x65\x6c\x2d\x64\x65\x63\x6c\x61\x72\x61\x74\x69\x6f\x6e"
  "\x73\x24\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x70\x61\x63\x6b\x61"
  "\x67\x65\x2d\x6f\x70\x74\x69\x6d\x69\x7a\x61\x74\x69\x6f\x6e\x2d"
  "\x6c\x65\x76\x65\x6c\x1e\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x61"
  "\x73\x73\x75\x6d\x65\x2d\x73\x61\x66\x65\x2d\x66\x69\x78\x6e\x75"
  "\x6d\x73\x3f\x16\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x61\x76\x6f"
  "\x69\x64\x2d\x73\x63\x6f\x64\x65\x3f\x1d\x63\x6f\x6d\x70\x69\x6c"
  "\x65\x72\x3a\x63\x6f\x6d\x70\x72\x65\x73\x73\x2d\x74\x6f\x70\x2d"
  "\x6c\x65\x76\x65\x6c\x3f\x1a\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a"
  "\x63\x72\x6f\x73\x73\x2d\x63\x6f\x6d\x70\x69\x6c\x69\x6e\x67\x3f"
  "\x27\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x63\x6f\x61\x6c\x65\x73"
  "\x63\x69\x6e\x67\x2d\x63\x6f\x6e\x73\x74\x61\x6e\x74\x2d\x77\x61"
  "\x72\x6e\x69\x6e\x67\x73\x3f\x1c\x63\x6f\x6d\x70\x69\x6c\x65\x72"
  "\x3a\x75\x73\x65\x2d\x6d\x75\x6c\x74\x69\x63\x6c\x6f\x73\x75\x72"
  "\x65\x73\x3f\x22\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x6f\x70\x65"
  "\x6e\x2d\x63\x6f\x64\x65\x2d\x66\x6c\x6f\x6e\x75\x6d\x2d\x63\x68"
  "\x65\x63\x6b\x73\x3f\x20\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x67"
  "\x65\x6e\x65\x72\x61\x74\x65\x2d\x73\x74\x61\x63\x6b\x2d\x63\x68"
  "\x65\x63\x6b\x73\x3f\x1f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x67"
  "\x65\x6e\x65\x72\x61\x74\x65\x2d\x74\x79\x70\x65\x2d\x63\x68\x65"
  "\x63\x6b\x73\x3f\x20\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x67\x65"
  "\x6e\x65\x72\x61\x74\x65\x2d\x72\x61\x6e\x67\x65\x2d\x63\x68\x65"
  "\x63\x6b\x73\x3f\x21\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x69\x6e"
  "\x74\x65\x72\x73\x70\x65\x72\x73\x65\x2d\x72\x74\x6c\x2d\x69\x6e"
  "\x2d\x6c\x61\x70\x3f\x1d\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x67"
  "\x65\x6e\x65\x72\x61\x74\x65\x2d\x6c\x61\x70\x2d\x66\x69\x6c\x65"
  "\x73\x3f\x1d\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x67\x65\x6e\x65"
  "\x72\x61\x74\x65\x2d\x72\x74\x6c\x2d\x66\x69\x6c\x65\x73\x3f\x1f"
  "\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x6f\x70\x65\x6e\x2d\x63\x6f"
  "\x64\x65\x2d\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x73\x3f\x0e\x63"
  "\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x63\x73\x65\x3f\x1f\x63\x6f\x6d"
  "\x70\x69\x6c\x65\x72\x3a\x61\x6e\x61\x6c\x79\x7a\x65\x2d\x73\x69"
  "\x64\x65\x2d\x65\x66\x66\x65\x63\x74\x73\x3f\x20\x63\x6f\x6d\x70"
  "\x69\x6c\x65\x72\x3a\x6f\x70\x74\x69\x6d\x69\x7a\x65\x2d\x65\x6e"
  "\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x73\x3f\x1f\x63\x6f\x6d\x70"
  "\x69\x6c\x65\x72\x3a\x69\x6d\x70\x6c\x69\x63\x69\x74\x2d\x73\x65"
  "\x6c\x66\x2d\x73\x74\x61\x74\x69\x63\x3f\x1f\x63\x6f\x6d\x70\x69"
  "\x6c\x65\x72\x3a\x63\x61\x63\x68\x65\x2d\x66\x72\x65\x65\x2d\x76"
  "\x61\x72\x69\x61\x62\x6c\x65\x73\x3f\x1b\x63\x6f\x6d\x70\x69\x6c"
  "\x65\x72\x3a\x63\x6f\x64\x65\x2d\x63\x6f\x6d\x70\x72\x65\x73\x73"
  "\x69\x6f\x6e\x3f\x23\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x70\x72"
  "\x65\x73\x65\x72\x76\x65\x2d\x64\x61\x74\x61\x2d\x73\x74\x72\x75"
  "\x63\x74\x75\x72\x65\x73\x3f\x19\x63\x6f\x6d\x70\x69\x6c\x65\x72"
  "\x3a\x73\x68\x6f\x77\x2d\x73\x75\x62\x70\x68\x61\x73\x65\x73\x3f"
  "\x16\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x73\x68\x6f\x77\x2d\x70"
  "\x68\x61\x73\x65\x73\x3f\x1a\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a"
  "\x73\x68\x6f\x77\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x73\x3f"
  "\x1c\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x73\x68\x6f\x77\x2d\x74"
  "\x69\x6d\x65\x2d\x72\x65\x70\x6f\x72\x74\x73\x3f\x10\x63\x6f\x6d"
  "\x70\x69\x6c\x65\x72\x3a\x6e\x6f\x69\x73\x79\x3f\x20\x63\x6f\x6d"
  "\x70\x69\x6c\x65\x72\x3a\x63\x6f\x6d\x70\x69\x6c\x65\x2d\x62\x79"
  "\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x73\x3f\x2a\x63\x6f\x6d"
  "\x70\x69\x6c\x65\x72\x3a\x65\x6e\x61\x62\x6c\x65\x2d\x69\x6e\x74"
  "\x65\x67\x72\x61\x74\x69\x6f\x6e\x2d\x64\x65\x63\x6c\x61\x72\x61"
  "\x74\x69\x6f\x6e\x73\x3f\x20\x05\x10\x64\x65\x66\x69\x6e\x65\x2d"
  "\x6d\x75\x6c\x74\x69\x70\x6c\x65\x02\x02\x06\x80\x80\x04\x01\x04"
  "\x81\x81\x02\x05\x0d";

SCHEME_OBJECT *
switch_so_data_055d1f72062c8b11 (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_switch_so_data_055d1f72062c8b11 [0]))), (sizeof (prog_switch_so_data_055d1f72062c8b11)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_6]));
}

DECLARE_COMPILED_DATA_NS ("switch.so", switch_so_data_055d1f72062c8b11)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("switch.so", "eefd98481537b2be")

==> mit-scheme-c-9.2.tar.gz: mit-scheme-c-9.2/src/compiler/base/switch.c <==
/* Emacs: this is -*- C -*- code, */
/* generated 2014-05-17T03:05:13-07 by Liar version 4.118. */

#include "liarc.h"

#define LABEL_5 3
#define LABEL_6 5
#define ENVIRONMENT_LABEL_3 12
#define DEBUGGING_LABEL_2 11
#define OBJECT_1 10
#define OBJECT_0 9
#define GLOBAL_EXECUTE_CACHE_4 7
#define FREE_REFERENCES_LABEL_0 6
#define NUMBER_OF_LINKER_SECTIONS_1 1

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
switch_so_c307f1f46bc6dbee (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl ATTRIBUTE((unused));
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5);
      goto label_3;

    case 1:
      current_block = (Rpc - LABEL_6);
      goto expression_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_1)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_5])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_3)
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd6.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_1]);
  (Rsp [2]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_4]));

INVOKE_INTERFACE_TARGET_4
}

int
decl_switch_so_c307f1f46bc6dbee (void)
{
  return (0);
}

DECLARE_COMPILED_CODE ("switch.so", 2, decl_switch_so_c307f1f46bc6dbee, switch_so_c307f1f46bc6dbee)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_switch_so_data_c307f1f46bc6dbee [1141] =
  "\x23\x01\x51\x1d\x0c\x06\x0d\x0d\x08\x89\x08\x88\x0d\x07\x07\x06"
  "\x06\x06\x06\x06\x07\x07\x07\x07\x06\x06\x07\x07\x07\x07\x07\x07"
  "\x07\x06\x06\x06\x06\x06\x07\x07\x07\x17\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x17\x28\x0d\x26\x22\x29\x22"
  "\x29\x21\x17\x02\x59\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f"
  "\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x6d\x69\x74\x2d\x73\x63\x68"
  "\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x32\x2f"
  "\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x32"
  "\x2f\x73\x72\x63\x2f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x2f\x62\x61"
  "\x73\x65\x2f\x73\x77\x69\x74\x63\x68\x2e\x69\x6e\x66\x09\x75\x75"
  "\x6f\x2d\x6c\x69\x6e\x6b\x04\x61\x6c\x6c\x07\x68\x79\x62\x72\x69"
  "\x64\x20\x17\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x70\x68\x61\x73"
  "\x65\x2d\x77\x72\x61\x70\x70\x65\x72\x28\x63\x6f\x6d\x70\x69\x6c"
  "\x65\x72\x3a\x64\x65\x66\x61\x75\x6c\x74\x2d\x74\x6f\x70\x2d\x6c"
  "\x65\x76\x65\x6c\x2d\x64\x65\x63\x6c\x61\x72\x61\x74\x69\x6f\x6e"
  "\x73\x24\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x70\x61\x63\x6b\x61"
  "\x67\x65\x2d\x6f\x70\x74\x69\x6d\x69\x7a\x61\x74\x69\x6f\x6e\x2d"
  "\x6c\x65\x76\x65\x6c\x1e\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x61"
  "\x73\x73\x75\x6d\x65\x2d\x73\x61\x66\x65\x2d\x66\x69\x78\x6e\x75"
  "\x6d\x73\x3f\x16\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x61\x76\x6f"
  "\x69\x64\x2d\x73\x63\x6f\x64\x65\x3f\x1d\x63\x6f\x6d\x70\x69\x6c"
  "\x65\x72\x3a\x63\x6f\x6d\x70\x72\x65\x73\x73\x2d\x74\x6f\x70\x2d"
  "\x6c\x65\x76\x65\x6c\x3f\x1a\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a"
  "\x63\x72\x6f\x73\x73\x2d\x63\x6f\x6d\x70\x69\x6c\x69\x6e\x67\x3f"
  "\x27\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x63\x6f\x61\x6c\x65\x73"
  "\x63\x69\x6e\x67\x2d\x63\x6f\x6e\x73\x74\x61\x6e\x74\x2d\x77\x61"
  "\x72\x6e\x69\x6e\x67\x73\x3f\x1c\x63\x6f\x6d\x70\x69\x6c\x65\x72"
  "\x3a\x75\x73\x65\x2d\x6d\x75\x6c\x74\x69\x63\x6c\x6f\x73\x75\x72"
  "\x65\x73\x3f\x22\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x6f\x70\x65"
  "\x6e\x2d\x63\x6f\x64\x65\x2d\x66\x6c\x6f\x6e\x75\x6d\x2d\x63\x68"
  "\x65\x63\x6b\x73\x3f\x20\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x67"
  "\x65\x6e\x65\x72\x61\x74\x65\x2d\x73\x74\x61\x63\x6b\x2d\x63\x68"
  "\x65\x63\x6b\x73\x3f\x1f\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x67"
  "\x65\x6e\x65\x72\x61\x74\x65\x2d\x74\x79\x70\x65\x2d\x63\x68\x65"
  "\x63\x6b\x73\x3f\x20\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x67\x65"
  "\x6e\x65\x72\x61\x74\x65\x2d\x72\x61\x6e\x67\x65\x2d\x63\x68\x65"
  "\x63\x6b\x73\x3f\x21\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x69\x6e"
  "\x74\x65\x72\x73\x70\x65\x72\x73\x65\x2d\x72\x74\x6c\x2d\x69\x6e"
  "\x2d\x6c\x61\x70\x3f\x1d\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x67"
  "\x65\x6e\x65\x72\x61\x74\x65\x2d\x6c\x61\x70\x2d\x66\x69\x6c\x65"
  "\x73\x3f\x1d\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x67\x65\x6e\x65"
  "\x72\x61\x74\x65\x2d\x72\x74\x6c\x2d\x66\x69\x6c\x65\x73\x3f\x1f"
  "\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x6f\x70\x65\x6e\x2d\x63\x6f"
  "\x64\x65\x2d\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x73\x3f\x0e\x63"
  "\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x63\x73\x65\x3f\x1f\x63\x6f\x6d"
  "\x70\x69\x6c\x65\x72\x3a\x61\x6e\x61\x6c\x79\x7a\x65\x2d\x73\x69"
  "\x64\x65\x2d\x65\x66\x66\x65\x63\x74\x73\x3f\x20\x63\x6f\x6d\x70"
  "\x69\x6c\x65\x72\x3a\x6f\x70\x74\x69\x6d\x69\x7a\x65\x2d\x65\x6e"
  "\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x73\x3f\x1f\x63\x6f\x6d\x70"
  "\x69\x6c\x65\x72\x3a\x69\x6d\x70\x6c\x69\x63\x69\x74\x2d\x73\x65"
  "\x6c\x66\x2d\x73\x74\x61\x74\x69\x63\x3f\x1f\x63\x6f\x6d\x70\x69"
  "\x6c\x65\x72\x3a\x63\x61\x63\x68\x65\x2d\x66\x72\x65\x65\x2d\x76"
  "\x61\x72\x69\x61\x62\x6c\x65\x73\x3f\x1b\x63\x6f\x6d\x70\x69\x6c"
  "\x65\x72\x3a\x63\x6f\x64\x65\x2d\x63\x6f\x6d\x70\x72\x65\x73\x73"
  "\x69\x6f\x6e\x3f\x23\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x70\x72"
  "\x65\x73\x65\x72\x76\x65\x2d\x64\x61\x74\x61\x2d\x73\x74\x72\x75"
  "\x63\x74\x75\x72\x65\x73\x3f\x19\x63\x6f\x6d\x70\x69\x6c\x65\x72"
  "\x3a\x73\x68\x6f\x77\x2d\x73\x75\x62\x70\x68\x61\x73\x65\x73\x3f"
  "\x16\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x73\x68\x6f\x77\x2d\x70"
  "\x68\x61\x73\x65\x73\x3f\x1a\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a"
  "\x73\x68\x6f\x77\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x73\x3f"
  "\x1c\x63\x6f\x6d\x70\x69\x6c\x65\x72\x3a\x73\x68\x6f\x77\x2d\x74"
  "\x69\x6d\x65\x2d\x72\x65\x70\x6f\x72\x74\x73\x3f\x10\x63\x6f\x6d"
  "\x70\x69\x6c\x65\x72\x3a\x6e\x6f\x69\x73\x79\x3f\x20\x63\x6f\x6d"
  "\x70\x69\x6c\x65\x72\x3a\x63\x6f\x6d\x70\x69\x6c\x65\x2d\x62\x79"
  "\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x73\x3f\x2a\x63\x6f\x6d"
  "\x70\x69\x6c\x65\x72\x3a\x65\x6e\x61\x62\x6c\x65\x2d\x69\x6e\x74"
  "\x65\x67\x72\x61\x74\x69\x6f\x6e\x2d\x64\x65\x63\x6c\x61\x72\x61"
  "\x74\x69\x6f\x6e\x73\x3f\x20\x05\x10\x64\x65\x66\x69\x6e\x65\x2d"
  "\x6d\x75\x6c\x74\x69\x70\x6c\x65\x02\x02\x06\x80\x80\x04\x01\x04"
  "\x81\x81\x02\x05\x0d";

SCHEME_OBJECT *
switch_so_data_c307f1f46bc6dbee (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_switch_so_data_c307f1f46bc6dbee [0]))), (sizeof (prog_switch_so_data_c307f1f46bc6dbee)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_6]));
}

DECLARE_COMPILED_DATA_NS ("switch.so", switch_so_data_c307f1f46bc6dbee)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("switch.so", "6b5b44a8acb75e97")
